CheckoutFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CheckoutFlutterPlatform
Implementers

Constructors

CheckoutFlutterPlatform()
Constructs a CheckoutFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCheckout({required Map<String, dynamic> configurations, dynamic onClose()?, dynamic onReady()?, dynamic onSuccess(String)?, dynamic onError(String)?, dynamic onCancel()?}) → Future<bool>
Start the checkout process with configurations and callbacks
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CheckoutFlutterPlatform
The default instance of CheckoutFlutterPlatform to use.
getter/setter pair